use Image::BMP;
use strict;
	print "Bitmap2List- A program that converts bitmap images to stat sprite lists.\nPlease enter the file name: ";
	my $filename;
	until ($filename =~ /\.bmp$/)
	{
		chomp($filename = <STDIN>);
		print "Invalid file extension. Please try again: " if $filename !~ /\.bmp$/;
	}
	my $bitmap = new Image::BMP(file => $filename);
	my $width = $bitmap->{Width};
	my $height = $bitmap->{Height};
	die "This program only supports bitmaps with a height less than or equal to 96 pixels or a width less than or equal to 64 pixels" if $width > 64 || $height > 96;
	my ($x,$y) = (0,0);
	my @xarray;
	my @yarray;
	print "Parsing...\n";
	until ($x == $width - 1 && $y == $height - 1)
	{
		my ($r,$g,$b) = $bitmap->xy_rgb($x,$y);
		if ($r + $g + $b == 0)
		{
			push @xarray,$x;
			push @yarray,($width - $y);
		}
		$x++;
		if ($x > $width - 1)
		{
			$x = 0;
			$y++;
		}
	}
	$bitmap->close;
	print "Finished! Writing list data to x.txt and y.txt.\n";
	open(FILEX,">x.txt");
	open(FILEY,">y.txt");
	$" = "\n";
	print FILEX "@xarray";
	print FILEY "@yarray";
	close FILEX;
	close FILEY;
__END__

=head1 NAME

Bitmap2List Converter

=head1 AUTHOR

Roberto Sanchez

=head1 DESCRIPTION

This program facilitates the creation of lists used in statistical sprites from bitmap images. The lists have only been tested in the Ti-83/84 Plus calculators. However, using TI-Connect may make the lists compatible with other calculators supported by TI-Connect. Also, this program only recognizes black and white so keep that in mind when creating your sprites. It was created using the perl2exe utility program. 

=head1 REQUIREMENTS

To use this program completely, the TI-Connect Data Editor is required. However, if you are willing to manually type in the list data on your calculator, then you don't need TI-Connect. Additionally, the EXE was compiled for Windows. If you are using other operating systems and have the Perl Interpreter installed, you will need to install the Image-BMP module available at cpan.org. The program only recognizes black and white pixels, and the bitmap file must be no more than 96 pixels wide and 64 pixels high. If the sprite requires lists larger than 999 elements, try to reduce the amount of pixels set.

=head1 FILES

Bitmap2List.pl- This is the perl script/source code of the program, written in Perl.
Bitmap2List.exe- This is the program you run. It only works on Windows.
Bitmap2List.html- The file you are reading right now. This html file was created using the pod2html Perl utility.

=head1 INSTRUCTIONS

=over 4

=item 1. Draw your sprite and save it as a .bmp file. Please remember that this program only recognizes black and white pixels. Also remember to save the .bmp to the folder where this program is stored.

=item 2. Open the TI-Connect Data Editor.

=item 3. Click File->Import.

=item 4. Import the files x.txt and y.txt.

=item 5. Send the lists to your calculator.

=item 6. The two lists will be X and Y for the x and y pixels.

=back

=head1 POSSIBLE FUTURE UPDATES

=over 4

=item Allow the program to create TI lists on its own.

=item Allow the program to produce a TI string with the hex data for a sprite.

=back

=head1 CONTACT

Contact me at L<sanchez@stis.net> if you have any questions, requests, or criticism.

=cut